@@ -24,7 +24,7 @@ from vdsm.network.api import (setSafeNetworkConfig, setupNetworks,
                               change_numvfs, add_ovs_vhostuser_port,
                               network_caps, ovs_bridge,
                               add_sourceroute, remove_sourceroute,
-                              remove_ovs_port)
+                              remove_ovs_port, get_lldp_info)
 from vdsm.network.restore_net_config import restore
 from vdsm.network.sysctl import set_rp_filter_loose, set_rp_filter_strict
 from vdsm.network.tc import setPortMirroring, unsetPortMirroring
@@ -48,3 +48,4 @@ expose(set_rp_filter_strict)
 expose(add_sourceroute)
 expose(remove_sourceroute)
 expose(remove_ovs_port)
+expose(get_lldp_info)
