@@ -1,5 +1,5 @@
 #
-# Copyright 2014-2017 Red Hat, Inc.
+# Copyright 2014-2018 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+from vdsm.api import vdsmapi
 from vdsm.common import cpuarch
 from vdsm.common import fileutils
 from vdsm.tool import configurator
@@ -25,6 +26,7 @@ from vdsm.tool.configfile import ConfigFile, ParserWrapper
 from vdsm.tool.configurators import abrt
 from vdsm.tool.configurators import libvirt
 from vdsm.tool.configurators import passwd
+from vdsm.tool.configurators import schema
 from vdsm.tool import UsageError
 from vdsm.tool import upgrade
 from vdsm import cpuinfo
@@ -39,6 +41,7 @@ import shutil
 import sys
 
 dirName = os.path.dirname(os.path.realpath(__file__))
+tmp_dir = tempfile.mkdtemp()
 
 FakeLibvirtFiles = libvirt.FILES
 FakeAbrtFiles = abrt.FILES
@@ -871,3 +874,21 @@ class UpgradeTests(TestCase):
         upgrade.apply_upgrade(upgrade_obj, 'test')
         self.assertFalse(upgrade_obj.ns.foo)
         self.assertSealed('test_again')
+
+
+class SchemaConfiguratorTest(TestCase):
+    def setUp(self):
+        self.tmp_dir = tempfile.mkdtemp()
+
+    def tearDown(self):
+        shutil.rmtree(self.tmp_dir)
+
+    def test_schema_created_and_removed(self):
+        with monkeypatch.MonkeyPatchScope(
+                [(vdsmapi, 'VDSM_CACHE_DIR', self.tmp_dir), ]):
+            schema.configure()
+            self.assertTrue(os.path.isfile(
+                os.path.join(self.tmp_dir, 'vdsm-api.pickle')))
+            schema.removeConf()
+            self.assertFalse(
+                os.path.exists(os.path.join(self.tmp_dir, 'vdsm-api.pickle')))
